# Obor
A simple pyTorch additional utilities library created for my paper

# Docs
This package contains

1. utils
contains:
- train()
- create_data_loader()

2. pruner
- prune_bbs()

# Created By
- name: Mohamad Doddy Sujatmiko
- email: doddy.s@protonmail.com
- github: github.com/doddy-s

# Change Log
## v0.1.0:
- initialize project
- add utils sub-package
- add train() function to simply train pytorch model
- add create_data_loader() function to simpy create dataloader needed for training

## v0.2.0:
- add pruner sub-package
- add prune_bbs() function to prune pytorch model with "BANK BALANCE SPARSITY" method

### v0.2.1:
- add type annotation to train() and craete_data_loader()
- minor print change